#!/bin/sh

. /etc/mnismail/mnismail.cfg



get_tmpfile()
{
tmpfile1=$TMPDIR/mail.$$
secondes=`date +%s`
>$tmpfile1
inode=`stat -c %i $tmpfile1`
tmpfile=$TMPDIR/mail_${secondes}_${inode}_$$
mv $tmpfile1 $tmpfile
}

check()
{
	[[ $got_f == 0 && $1 == "From:" ]] && got_f=1 && from=$2 && return
	[[ $got_t == 0 && $1 == "To:" ]] && got_t=1 && to="$*" && return
	[[ $got_c == 0 && "$1" == "Subject:" ]] && got_s=1 && return
	[[ $got_c == 0 && "$*" == "In-Reply-To: $REPID" ]] && got=1 && return
	[[ $got_c == 0 && "$1" == "Cc:" ]] && got_c=1 && return
}

fqdn()
{
	echo $* | cut -d":" -f2 |cut -d"<" -f2 | cut -d">" -f1 | tr -d " "
}

handle_auth()
{
# If sender authenticated deliver it
	[ -f $AUTH_FROM/$from ] && rm $tmpfile && exit 0
	[ -f $AUTH_NET/$net ] && rm $tmpfile && exit 0
}

handle_blacklist()
{
# silently ignore black list
	[ -f $BLACKLIST/$from ] &&
		mnis_log "$0: blacklisted $from" &&
		mv $tmpfile $BLACKDIR &&
		exit 99
# ignore automatic black list too
	[ -f $TOO_OLD/$from ] &&
		mnis_log "$0: too_old $from" &&
		mv $tmpfile $BLACKDIR &&
		exit 99
}

############### main #########

got_f=0
got_t=0
got_c=0
got_s=0
got=0
get_tmpfile

while read C
do
	check $C
	echo $C >> $tmpfile
	if [ "$got_f" = "1" ]; then from=$C; got_f=2; fi
	if [ "$got_t" = "1" ]; then to=$C; got_t=2; fi
	if [ "$got_s" = "1" ]; then subject=`echo $C | sed -e "s/[*?.$! ]/_/g"` ; got_s=2; fi
	if [ "$got" = "1" ]; then confirm=$C; got=2; fi
	if [ "$got_c" = "1" ]; then liste=$C; got_c=2; fi
done


[[ "$SENDER" ]] && from=$SENDER
[[ "$SENDER" ]] || from=`fqdn $from`
to=`fqdn $to`

if [ "$from" = "" ]; then
	mnis_log "$0: unknown from"
	exit 99
fi


mnis_log "$0: from: $from to: $to tmpfile: $tmpfile subject: $subject"

net=`echo $from | cut -d"@" -f2`
name=`echo $from | cut -d"@" -f1`

#
# handle authorization
#
handle_auth

#
# handle blacklist
#
handle_blacklist


#
# handle bounces
#
if [ "$from" = "MAILER-DAEMON@ik58010.ikexpress.com" ]; then
	mnis_log "$0: bounce: $from $to"
	rm $tmpfile
	exit 99
fi

#
# Got the authentication
# process it and deliver it
#

if [ "$confirm" != "" ]; then
	mnis_log "$0: from: $from to: $to CONFIRMED"
	do_confirm $from
	exit 0
fi



# look at CC for a list
liste=$(echo "$liste" | sed -e "s/[<>]//g")
if [ "$liste" != "" ]; then
for i in $liste
do
	mnis_log "Liste in CC: $liste: found $i"
	[ -f $LISTE/$i ] && exit 0
done
fi

# look at To for a list
liste=$(echo "$to" | sed -e "s/[<>]//g")
[ "$liste" = "" ] && exit 99
if [ "$liste" != "" ]; then
for i in $liste
do
	mnis_log "Liste in TO: $liste: found $i"
	[ -f $LISTE/$i ] && exit 0
done
fi

mnis_log handle mail from $from to $to
#
# In other cases wait for confirmation
# do not process further delivery
[ -f $CONFIRM/$from ] && wait_confirm $tmpfile $from $to $subject
[ -f $CONFIRM/$from ] || ask_confirm $tmpfile $from $to $subject

exit 99

